#GIT_CMT=30ea5174c0c98d12de0ae201d045e21b0c21dfad
# Copyright(c) 2015,2016 Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 3.0.1

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}

# Docker group name
%global docker_group    docker


Summary:        OpenStack Kolla Deployment
Name:           openstack-kolla
Version:        %{package_version}
Release:    251.el7
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kolla-3.0.1.tar.bz2
BuildArch:      noarch

BuildRequires:  python                      >= 2.6
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0
BuildRequires:  git                         >= 1.7.1


%description
OpenStack Kolla meta package


%prep
%setup -q -n %{name}-%{version}


%build
# Generate a temporary pkg-info file to make pbr happy
git init .
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
if [[ -z "${PKGINFO_VERSION}" ]]
then
    _v=$(sed \
          -n \
          -e '/^openstack_release/ s/openstack_release:.*"\(.*\)"/\1/p' \
          ansible/group_vars/all.yml)
     [[ ! -z "${_v}" ]] \
        && PKGINFO_VERSION="${_v}" \
        || PKGINFO_VERSION="%{package_version}"
fi
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

# Build the package
%{__python} setup.py build


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0755 -p %{buildroot}%{_datadir}/kolla
cat >%{buildroot}%{_datadir}/kolla/LICENSE.TXT <<EOF
Oracle OpenStack for Oracle Linux is a management software package
comprised of various OpenStack components combined with independent software
programs that operate as OpenStack services. These independent programs
include parts of MySQL Community Edition, Oracle Linux and MySQL Cluster
Community Edition. The license for each OpenStack component, as well as the
licenses for each independent program, can be found in the root folder for
each component and/or program or in the specific Docker Container or RPM
package.
EOF

mkdir -m 0755 -p %{buildroot}%{_sysconfdir}/kolla
mkdir -m 0755 -p %{buildroot}%{_sysconfdir}/kolla/config
cp -r etc/kolla/* %{buildroot}%{_sysconfdir}/kolla/

[[ -d /etc/kolla/config ]] && find %{buildroot}%{_sysconfdir}/kolla/config -type f | xargs chmod 0664
[[ -d /etc/kolla/config ]] && find %{buildroot}%{_sysconfdir}/kolla/config -type d | xargs chmod 0775

chmod 0600 %{buildroot}%{_sysconfdir}/kolla/passwords.yml
mv %{buildroot}%{_sysconfdir}/kolla/globals.yml \
   %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
chmod 0664 %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__

# Create the Kolla sudo file
mkdir -p %{buildroot}%{_sysconfdir}/sudoers.d
_group=%{kolla_group}
cat >%{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user} <<__EOF__
Defaults: %{kolla_user} env_keep += "OS_AUTH_URL OS_TENANT_ID OS_TENANT_NAME OS_PROJECT_NAME"
Defaults: %{kolla_user} env_keep += "OS_USERNAME OS_PASSWORD  OS_REGION_NAME REGISTRY"
Defaults: %{kolla_user} env_keep += "OS_PROJECT_DOMAIN_ID     OS_USER_DOMAIN_ID"
Defaults: %{kolla_user} env_keep += "OS_VOLUME_API_VERSION    OS_IDENTITY_API_VERSION"

Defaults: %{kolla_user} !requiretty
Cmnd_Alias KOLLA_ADMIN_CMDS = ALL
%{kolla_user} ALL = (root) NOPASSWD: KOLLA_ADMIN_CMDS

Defaults: %${_group} !requiretty
Cmnd_Alias KOLLA_CMDS = /usr/bin/ansible, /usr/bin/ansible-playbook, /bin/ls, /bin/id
%${_group} ALL = (%{kolla_user}) NOPASSWD: KOLLA_CMDS
__EOF__
chmod 0600 %{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user}

mv -f %{buildroot}%{_datadir}/kolla/ansible/inventory \
      %{buildroot}%{_datadir}/kolla/ansible/inventory_samples

%clean
rm -rf %{buildroot}


%files
%defattr(-, root, root)
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%attr(0444, root, root) %{_datadir}/kolla/LICENSE.TXT
%{python_sitelib}/kolla-*.egg-info


%package -n     openstack-kolla-devel
Summary:        OpenStack Kolla development files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       GitPython                   >= 1.0.1
Requires:       python-gitdb                >= 0.6.4
Requires:       python-pbr                  >= 1.3.0
Requires:       python-jinja2               >= 2.8
Requires:       openstack-kolla-ansible     = %{package_version}-%{release}


%description -n openstack-kolla-devel
Files used to develop Kolla OpenStack Docker images.


%files -n       openstack-kolla-devel
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-build
%{_sysconfdir}/kolla/kolla-build.conf
%{_datadir}/kolla
%{python_sitelib}/*
%exclude %{_datadir}/kolla/LICENSE.TXT
%exclude %{_datadir}/kolla/ansible
%exclude %{_datadir}/kolla/tools/cleanup-containers
%exclude %{_datadir}/kolla/tools/cleanup-host
%exclude %{_datadir}/kolla/tools/cleanup-images
%exclude %{_datadir}/kolla/tools/stop-containers
%exclude %{_datadir}/kolla/tools/validate-docker-execute.sh
%exclude %{python_sitelib}/kolla-*.egg-info
%exclude %{python_sitelib}/kolla/__init__*
%exclude %{python_sitelib}/kolla/cmd/__init__*
%exclude %{python_sitelib}/kolla/cmd/genpwd*


%package -n     openstack-kolla-ansible
Summary:        OpenStack Kolla Ansible playbooks and supporting files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sed                         >= 4.2.1
Requires:       ansible                     >= 2.1.0
Requires:       ansible                     <  2.2.0
Requires:       python-jinja2               >= 2.8
Requires:       python-netaddr              >= 0.7.5
Requires:       openstack-kolla-user        = %{package_version}-%{release}


%description -n openstack-kolla-ansible
Ansible playbooks and support files to deploy Kolla in Docker containers.


%files -n       openstack-kolla-ansible
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%config(noreplace) %{_sysconfdir}/kolla
%config(noreplace) %{_sysconfdir}/kolla/config/nova.conf
%config(noreplace) %{_sysconfdir}/kolla/passwords.yml
%config(noreplace) %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-ansible
%{_datadir}/kolla/ansible
%{_datadir}/kolla/tools/cleanup-containers
%{_datadir}/kolla/tools/cleanup-host
%{_datadir}/kolla/tools/cleanup-images
%{_datadir}/kolla/tools/stop-containers
%{_datadir}/kolla/tools/validate-docker-execute.sh
%{python_sitelib}/kolla/__init__*
%{python_sitelib}/kolla/cmd/__init__*
%{python_sitelib}/kolla/cmd/genpwd*
%{python_sitelib}/kolla/cmd/mergepwd*
%{_bindir}/kolla-genpwd
%{_bindir}/kolla-mergepwd
%exclude %{_sysconfdir}/kolla/kolla-build.conf
%exclude %{_sysconfdir}/kolla/template-overrides.j2


%pre -n         openstack-kolla-ansible
case "$*" in
    0)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    if ! test -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__ && \
         test -f %{_sysconfdir}/kolla/globals.yml
    then
        mv %{_sysconfdir}/kolla/globals.yml \
           %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
        echo '# See: %{_datadir}/kolla/ansible/group_vars/__GLOBAL__' >%{_sysconfdir}/kolla/globals.yml
        chown %{kolla_user}:%{kolla_group} %{_sysconfdir}/kolla/globals.yml
        chmod 0664 %{_sysconfdir}/kolla/globals.yml
    fi
    if   test -f %{_sysconfdir}/kolla/passwords.yml && \
       ! grep -q '^nova_ssh_key:' %{_sysconfdir}/kolla/passwords.yml
    then
        cp -f %{_sysconfdir}/kolla/passwords.yml \
              %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
    #
    # For upgrade from 2.1.1, we'll create an augment to adjust nova.conf
    # Previous augments will be saved to .rpmsave, user should merge them
    #
    # If previous altered augment file exists and the following is not in
    # said file then it must be manually added prior to upgrade.
    # [neutron]
    # username = nova
    #
    groups_dir=%{_datadir}/kolla/ansible/group_vars
    globals_yml=${groups_dir}/__GLOBAL__
    all_yml=${groups_dir}/all.yml
    if grep -q '^openstack_release.*:.*"2\.[01]\.[012].*' ${globals_yml} || \
       grep -q '^openstack_release.*:.*"2\.[01]\.[012].*' ${all_yml} && \
       [[ $(wc -c < %{_sysconfdir}/kolla/config/nova.conf) == "0" ]]
    then
        echo $'[neutron]\nusername = nova\n' >> %{_sysconfdir}/kolla/nova_augment
    fi
fi
exit 0


%post -n        openstack-kolla-ansible
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Operations to support group / host variables
#
if ! test -d %{_datadir}/kolla/ansible/host_vars
then
    mkdir -m 0775 -p %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
fi
chmod 0775 %{_datadir}/kolla/ansible/group_vars

if [[ "${inst_type}" == "update" ]]
then
    if test -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
    then
        mv -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave \
              %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    fi
    #
    # Use the default release tag if not using 'latest' tag
    #
    globals_yml=%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    if grep -q '^openstack_release.*:' ${globals_yml} && \
       ! grep -q '^openstack_release.*:.*latest.*' ${globals_yml}
    then
        sed -i \
            -e 's/^openstack_release.*:/#openstack_release:/' \
            ${globals_yml}
    fi
    rm -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmnew

    if test -f %{_sysconfdir}/kolla/passwords.yml.rpmsave && \
       test -f %{_sysconfdir}/kolla/passwords.yml
    then
        if test -f %{_sysconfdir}/kolla/passwords.yml.rpmnew
        then
            mv %{_sysconfdir}/kolla/passwords.yml.rpmnew %{_sysconfdir}/kolla/passwords.yml
        fi
        kolla-genpwd
        kolla-mergepwd --old %{_sysconfdir}/kolla/passwords.yml.rpmsave \
                       --new %{_sysconfdir}/kolla/passwords.yml \
                       --final %{_sysconfdir}/kolla/passwords.yml
        rm -f %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
    #
    # If augment is set in pre openstack-kolla-ansible then
    # update nova augment file.
    #
    if [[ -f %{_sysconfdir}/kolla/nova_augment ]]
    then
        mv %{_sysconfdir}/kolla/nova_augment %{_sysconfdir}/kolla/config/nova.conf
        chown %{kolla_user}:%{kolla_group} %{_sysconfdir}/kolla/config/nova.conf
    fi
fi

#
# This forces the Oracle default values without changing what the user
#      might have set on his own
#
sed -i \
    -e 's/^docker_namespace:.*/docker_namespace: "openstack"/' \
    -e 's/^kolla_base_distro:.*/kolla_base_distro: "ol"/' \
    -e 's/^kolla_install_type:.*/kolla_install_type: "openstack"/' \
    -e 's/^openstack_release:.*/openstack_release: "%{package_version}"/' \
    -e 's/^keepalived_virtual_router_id:.*/virtual_router_id: "51"\
keepalived_virtual_router_id: "{{ virtual_router_id }}"/' \
    -e 's/^glance_backend_file:.*/glance_backend_file: "yes"/' \
    -e 's/^glance_backend_ceph:.*/glance_backend_ceph: "no"/' \
    -e 's/^cinder_backend_ceph:.*/cinder_backend_ceph: "no"/' \
    -e 's/^enable_cinder_backend_lvm:.*/enable_cinder_backend_lvm: "{{ \x27no\x27 if nova_libvirt_virt_type == \x27xen\x27 else \x27yes\x27 }}"/' \
    -e 's/^enable_cinder_backend_iscsi:.*/enable_cinder_backend_iscsi: "yes"/' \
    -e 's/^enable_cinder:.*/enable_cinder: "yes"/' \
    -e 's/^enable_multipathd:.*/enable_multipathd: "yes"/' \
    -e 's/^enable_murano:.*/enable_murano: "yes"/' \
    -e 's/^enable_central_logging:.*/enable_central_logging: "yes"/' \
    -e 's/^ceilometer_database_type:.*/ceilometer_database_backend: "mysql"\
ceilometer_database_type: "{{ ceilometer_database_backend }}"/' \
    -e 's/^enable_aodh:.*/enable_aodh: "{{ \x27yes\x27 if enable_ceilometer | bool else \x27no\x27 }}"/' \
    -e 's/^kolla_external_fqdn:.*/kolla_external_address: "{{ kolla_internal_fqdn if kolla_external_vip_address == kolla_internal_vip_address else kolla_external_vip_address }}"\
kolla_external_fqdn: "{{ kolla_external_address }}"/' \
    -e 's/^docker_registry:.*/docker_registry: "container-registry.oracle.com"/' \
    %{_datadir}/kolla/ansible/group_vars/all.yml

echo 'nova_hw_disk_discard: ""' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'cinder_iscsi_helper: "lioadm"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo "mysqlcluster_api_first_node_address: \"{{ hostvars[groups['mysqlcluster-api'][0]]['ansible_' + hostvars[groups['mysqlcluster-api'][0]]['api_interface']]['ipv4']['address'] }}\"" >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'ceilometer_database_address: "{{ mysqlcluster_api_first_node_address }}"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'ceilometer_database_mysql_address: "{{ ceilometer_database_address }}"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'ceilometer_database_mongodb_address: "{{ ceilometer_database_address }}"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
exit 0


%postun -n      openstack-kolla-ansible
case "$*" in
    0)
        #
        # Remove/Erase package
        #
        inst_type="remove"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    #
    # Change the permissions of the config files (bug 21983235)
    #
    _stat="$(stat --format="%U:%G:%a" %{_sysconfdir}/kolla/config 2>/dev/null)"
    if [[ "${_stat}" == "%{kolla_user}:%{kolla_group}:755" ]]
    then
        chmod -f -R g+w %{_sysconfdir}/kolla/config
    fi
fi
exit 0



%package -n     openstack-kolla-utils
Summary:        OpenStack Kolla utilities.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       openstack-kolla             = %{package_version}


%description -n openstack-kolla-utils
Utilities for use with Kolla containers.


%files -n       openstack-kolla-utils
%attr(-, root, root) %doc LICENSE
%attr(755, root, root) %{_bindir}/docker-ostk



%package -n     openstack-kolla-user
Summary:        OpenStack Kolla user configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sudo                        >= 1.7
Requires:       openstack-kolla             = %{package_version}-%{release}
Requires:       shadow-utils                >= 4.1


%description -n openstack-kolla-user
Create kolla user for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-user
%attr(-, root, root) %doc LICENSE
%attr(0600, root, root) %{_sysconfdir}/sudoers.d/%{kolla_user}
%attr(0755, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla


%pre -n         openstack-kolla-user
/usr/sbin/groupadd -f -r %{docker_group} >/dev/null 2>&1
/usr/sbin/groupadd -f -r %{kolla_group}  >/dev/null 2>&1
if ! id %{kolla_user} >/dev/null 2>&1
then
    /usr/sbin/useradd \
      -b %{_datadir} \
      -c 'Kolla User' \
      -g %{kolla_group} \
      -G %{docker_group} \
      -m \
      -k /no_skel_dir \
      -N \
      -r \
      %{kolla_user}
    [[ $? -ne 0 ]] && exit 1
    chown -f %{kolla_user}:%{kolla_group} ~%{kolla_user}
    chmod -f 0750 ~%{kolla_user}
fi
exit 0


%post -n        openstack-kolla-user
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Setup sudoers for the user
#
if ! grep -q '^#include.*%{_sysconfdir}/sudoers.d' %{_sysconfdir}/sudoers
then
    echo '' >&2
    echo 'WARNING: %{_sysconfdir}/sudoers is NOT including the %{_sysconfdir}/sudoers.d files!!' >&2
    echo '         Appending to %{_sysconfdir}/sudoers directly' >&2
    echo '' >&2
    if ! grep -q '^%{kolla_user}.*NOPASSWD' %{_sysconfdir}/sudoers
    then
        cat %{_sysconfdir}/sudoers.d/%{kolla_user} >>%{_sysconfdir}/sudoers
    fi
fi

#
# Prepare the user for SSH access
#
if ! test -d ~%{kolla_user}/.ssh
then
    mkdir -p -m 0700 ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
fi
if ! test -f ~%{kolla_user}/.ssh/authorized_keys
then
    touch ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chmod 0600 ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
fi
exit 0



%package -n     openstack-kolla-preinstall
Summary:        OpenStack Kolla pre-install configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sudo                        >= 1.7
Requires:       docker-engine               >= 1.12.0
Requires:       docker-engine               <  1.13.0
Requires:       btrfs-progs                 >= 4.2.2

Requires:       python-docker-py            >= 1.8.1
Requires:       python-six                  >= 1.9.0
Requires:       openstack-kolla-user        = %{package_version}-%{release}


%description -n openstack-kolla-preinstall
Prepare a system for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-preinstall
%attr(-, root, root) %doc LICENSE


%post -n        openstack-kolla-preinstall
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Prevent 'Error! pty.fork() failed: out of pty devices' errors by forcing ptmxmode=666
#
if grep -q '^devpts' %{_sysconfdir}/fstab
then
    sed \
     -i \
     -e '/^devpts/ s/\(.*\)\(ptmxmode=[0-9]*\)\(.*\)/\1ptmxmode=666\3/' \
     %{_sysconfdir}/fstab
else
    echo 'devpts                  /dev/pts                devpts  rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666 0 0' >>%{_sysconfdir}/fstab
fi

#
# If this is an Oracle VM Server, prepare the server
#
if test -x %{_sbindir}/ovm2openstack
then
    if [[ ! -h /run ]]
    then
        [[ -d /run ]] && mv -f /run /run.rpmsave
        ln -s %{_var}/run /run
    fi

    [[ ! -d %{_sharedstatedir}/kolla%{_sharedstatedir}/nova ]] && \
        mkdir -p %{_sharedstatedir}/kolla%{_sharedstatedir}/nova

    [[ ! -e %{_sharedstatedir}/nova ]] && \
        ln -s %{_sharedstatedir}/kolla%{_sharedstatedir}/nova \
              %{_sharedstatedir}/nova

    [[ ! -d %{_sharedstatedir}/nova/instances ]] && \
        mkdir -p %{_sharedstatedir}/nova/instances

    #
    # Ideally this should get migrated into the ovm2openstack script
    #
    for svc in multipathd iscsi iscsid oswatcher ovm-consoled ovs-devmon
    do
        [[ ! -z "$(service ${svc} status 2>/dev/null|grep running)" ]] && \
            service ${svc} stop >/dev/null 2>&1
        [[ ! -z "$(chkconfig --list ${svc} 2>/dev/null|grep on)" ]] && \
            chkconfig ${svc} off >/dev/null 2>&1
        chkconfig --del ${svc} >/dev/null 2>&1
    done
    [[ -f /etc/multipath.conf ]] && [[ ! -f /etc/multipath.conf.ovm ]] && \
        mv -f /etc/multipath.conf /etc/multipath.conf.ovm

    restart_libvirtd=""
    if ! grep -q '^listen_addr.*127.0.0.1' \
                 %{_sysconfdir}/libvirt/libvirtd.conf >/dev/null 2>&1
    then
        cp -f -p %{_sysconfdir}/libvirt/libvirtd.conf \
                  %{_sysconfdir}/libvirt/libvirtd.conf.rpmsave
        sed \
         -i \
         -e '/#tcp_port/c\tcp_port = "16509"' \
         -e '/#listen_addr/c\listen_addr = "0.0.0.0"' \
         -e '/#unix_sock_ro_perm/c\unix_sock_ro_perms = "0777"' \
         -e '/#unix_sock_rw_perm/c\unix_sock_rw_perms = "0770"' \
         -e '/#unix_sock_dir/c\unix_sock_dir = "/var/run/libvirt"' \
         -e '/#log_level/c\log_level = 3' \
         -e '/#listen_tls/c\listen_tls = 0' \
         -e '/#listen_tcp/c\listen_tcp = 1' \
         -e '/#auth_tcp/c\auth_tcp = "none"' \
         %{_sysconfdir}/libvirt/libvirtd.conf
        sed \
         -i \
         -e '/#LIBVIRTD_ARGS/c\LIBVIRTD_ARGS="--listen"' \
         %{_sysconfdir}/sysconfig/libvirtd
         restart_libvirtd="restart"
    fi

    #
    # Only run the ovm2openstack if it has not been run before
    #
    if [[ ! -f %{_sysconfdir}/sysconfig/ovm2openstack ]]
    then
        %{_sbindir}/ovm2openstack >/dev/null 2>&1
    else
        #
        # ONLY restart libvirtd if the config was actually changed since it
        #      can kill VMs
        #
        if [[ ! -z "${restart_libvirtd}" ]]
        then
            service libvirtd restart >/dev/null 2>&1
        fi
    fi
    #
    # Added to enable iscsid and multipathd containers to start on OVM
    #
    echo '#!/bin/bash' > /etc/sysconfig/modules/configfs.modules
    echo 'exec /sbin/modprobe configfs > /dev/null 2>&1' >> /etc/sysconfig/modules/configfs.modules
    chmod 755 /etc/sysconfig/modules/configfs.modules
    /sbin/modprobe configfs
    #
    # Enable propagation of neutron dvr related namespace mounts for docker
    #
    cat > %{_sysconfdir}/rc.d/init.d/makeshared << "__EOF__"
#!/bin/sh
#       /etc/rc.d/init.d/makeshared
#       make-shared filesystem for neutron dvr
# chkconfig:   2345 94 94
# description: make-shared filesystem for neutron dvr

# Source function library.
. /etc/rc.d/init.d/functions

start() {
    mount --make-shared /
}

case "$1" in
    start)
        $1
        ;;
    stop)
        :
        ;;
    *)
        echo $"Usage: $0 {start|stop}"
        exit 2
        ;;
esac

exit $?
__EOF__

    chmod 755 %{_sysconfdir}/rc.d/init.d/makeshared
    chkconfig --add makeshared
    chkconfig makeshared on
    service makeshared start
    [[ -n "$(service docker status 2>/dev/null|grep running)" ]] && \
        service docker stop >/dev/null 2>&1
    [[ -z "$(chkconfig --list docker 2>/dev/null|grep on)" ]] && \
        chkconfig docker on >/dev/null 2>&1
    [[ -z "$(service docker status 2>/dev/null|grep running)" ]] && \
        service docker start >/dev/null 2>&1
elif test -x %{_bindir}/systemctl
then
    #
    # Set docker MountFlags=shared for neutron
    #
    mkdir -p %{_sysconfdir}/systemd/system/docker.service.d
    if ! test -f %{_sysconfdir}/systemd/system/docker.service.d/kolla.conf
    then
        cat > %{_sysconfdir}/systemd/system/docker.service.d/kolla.conf << __EOF__
[Service]
MountFlags=shared
__EOF__
        systemctl daemon-reload
        systemctl stop docker >/dev/null 2>&1
    fi
    [[ -n "$(systemctl show docker --property ActiveState|grep '=active')" ]] && \
        systemctl stop docker >/dev/null 2>&1
    [[ -z "$(systemctl show docker --property UnitFileState|grep '=enabled')" ]] && \
        systemctl enable docker >/dev/null 2>&1
    [[ -z "$(systemctl show docker --property ActiveState|grep '=active')" ]] && \
        systemctl start  docker >/dev/null 2>&1
fi
exit 0



%changelog
* Tue Mar 21 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-251.el7
- BUILDINFO: commit=30ea5174c0c98d12de0ae201d045e21b0c21dfad
- docker-engine 1.13 not supported (Kevin Loughnane)  

* Mon Mar 20 2017 Borne Mace <borne.mace@oracle.com> - 3.0.1-250.el7
- BUILDINFO: commit=ab81a69651524c0493bbc99424bbfcb3110a8cd8
- Updated rpm spec to put LICENSE.TXT in /usr/share/kolla (Borne Mace)

* Wed Mar 15 2017 mannamne <murali.annamneni@oracle.com> - 3.0.1-249.el7
- BUILDINFO: commit=702ac92cb6cd4c25a22ac9d5f01176f7cd504f7b
- Add new License Text to O3L 3.0.1 DockerImages and RPMs (mannamne)

* Sat Feb 18 2017 mannamne <murali.annamneni@oracle.com> - 3.0.1-248.el7
- BUILDINFO: commit=a0bdbce9b44882de1734d34dbb3d0f7b8c8ef675
- Remove magnum workarounds (mannamne)

* Wed Feb 15 2017 mannamne <murali.annamneni@oracle.com> - 3.0.1-247.el7
- BUILDINFO: commit=ee97d3e87992a82a87489eab1865dd44b52a59e3
- Workarounds for magnum (mannamne)

* Wed Feb 15 2017 mannamne <murali.annamneni@oracle.com> - 3.0.1-246.el7
- BUILDINFO: commit=bde2d374e9627cdbdf1d1e2382e93eed6f7f667d
- Fix Magnum trustee issues (Murali Annamneni)

* Tue Feb 14 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-245.el7
- BUILDINFO: commit=d9b2a4411955d0448b340704116e9a831a26bbf5
- Add internal sources for ironic-ui / magnum-ui (Paul Bourke)

* Tue Feb 14 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-244.el7
- BUILDINFO: commit=19269c4f242601efdef4d989e4192c89211ec7b6
- Install rabbitmq rpms from ca-artifacts (Paul Bourke)

* Mon Feb 13 2017 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-243.el7
- BUILDINFO: commit=3d5539a530aff20d972f1e4d9cf8b3688ba97769
- The docker-ostk should not hardcode its need for tty. (James McCarthy)

* Mon Feb 13 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-242.el7
- BUILDINFO: commit=b4e0c137e216c34f44d2a088e2020144a2508e11
- Install liberasure rpms from ca-artifacts (Paul Bourke)

* Mon Feb 13 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-241.el7
- BUILDINFO: commit=01a31e9915b148c5c92391284964f568d0236d53
- Use Internal PyPI mirror. (Kevin Loughnane)  
- Use Heka from ca-artifacts, part 2: do not copy previous RPM (Kevin Loughnane)

* Mon Feb 13 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-240.el7
- BUILDINFO: commit=aeb866d50b3f8ca032c2f39fc4fd720a26b366ea
- Use Heka from ca-artifacts (Kevin Loughnane)

* Thu Feb 09 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-239.el7
- BUILDINFO: commit=27d56d77b9558a5cd5ccb9c45c0f043868123cc0
- Take2: Bug 25523854 Kibana, Elasticsearch, Heka RPMs to use ca-artifacts (Kevin Loughnane)  
- Fix ironic template for Mitaka & InnoDB migrations (Paul Bourke)  
- Revert "Also sed ndbcluster in ironic_inspector" (Paul Bourke)

* Thu Feb 09 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-238.el7
- BUILDINFO: commit=19ee2be5a7d774982e1d510ddc91e5d20a9f97ac
- Bug 25523854 Kibana, Elasticsearch, Heka RPMs to use ca-artifacts (Kevin Loughnane)

* Thu Feb 09 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-237.el7
- BUILDINFO: commit=fd21b95ec44cdd063d84a2e809eb7f5f2940b4b0
- Bug 25523854 Kibana, Elasticsearch, Heka RPMs to use ca-artifacts (Kevin Loughnane)

* Wed Feb 08 2017 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-236.el7
- BUILDINFO: commit=c9c462c337529e96c4822cf7e12ea83008426562
- Allow configuration of HAProxy default timeouts (Vladislav Belogrudov)

* Wed Feb 08 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-235.el7
- BUILDINFO: commit=6a18f2fdb9bcd4cb20efc32891737c6637ad9b76
- Also sed ndbcluster in ironic_inspector (Paul Bourke)

* Tue Feb 07 2017 Sercan Acar <sercan.acar@oracle.com> - 3.0.1-234.el7
- BUILDINFO: commit=86f25194e0e741e2040b8a33df050833ff8dd6e4
- Add transport (AMQP) details for a connection with rabbitmq (Sercan Acar)

* Mon Feb 06 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-233.el7
- BUILDINFO: commit=7d619202e44402ef17461f62bf6045832853a31d
- Add dnsmasq to the oracle build profile (Paul Bourke)

* Fri Feb 03 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-232.el7
- BUILDINFO: commit=30074e1b8751b7b5325e2a0b2032f182fd1b4437
- Bug 25481157 - Magnum: change Rel Notes to allow magnum-conductor use a HTTP Proxy (Kevin Loughnane)

* Fri Feb 03 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-231.el7
- BUILDINFO: commit=400225f7a44eeed541c39c6faf0c6a794d153b56
- Fix ironic inspector (ansible) (Mauricio Lima)  
- Fix ironic inspector (docker) (Mauricio Lima)  
- Add kolla_toolbox module from upstream (Paul Bourke)

* Thu Feb 02 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-230.el7
- BUILDINFO: commit=4ad471f8d11bf05e1fbad17a927e02fc55c54718
- Bug 25489054 - Swift: account_quotas and container_quotas required for defcore (Kevin Loughnane)

* Thu Jan 26 2017 Murali <murali.annamneni@oracle.com> - 3.0.1-229.el7
- BUILDINFO: commit=66ffeb6a979c5e646704caeafa5d2bb0b17ccbae
- Replace InnoDB hardcoding with NDBCLUSTER (mannamne)  
- Fix hardcoded branch specifier in murano overrides (Paul Bourke)

* Thu Jan 26 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-228.el7
- BUILDINFO: commit=5f2096a3d16411cceaaf3e7a28cc8686557cc539
- Install patched oslo.middleware into openstack-base (Paul Bourke)   {CVE-2017-2592}

* Tue Jan 24 2017 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-227.el7
- BUILDINFO: commit=2a7ff2883323cf736702e3ae1b6fd431e75abfee
- Replace innodb hardcoding with ndbcluster (Paul Bourke)  
- Update kolla-build.conf references to o3l_3.0.next (Paul Bourke)

* Tue Jan 10 2017 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-226.el7
- BUILDINFO: commit=20cbb6fdb4daad65c74c10978081361ac3073e6b
- Update default docker_registry setting to container-registry.oracle.com (James McCarthy)

* Fri Jan 06 2017 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-225.el7
- BUILDINFO: commit=1c004ec088a10b458af448f699cc356b9610f7cd
- Update all murano packages during upgrade (Vladislav Belogrudov)

* Tue Jan 03 2017 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-224.el7
- BUILDINFO: commit=a9e848d3b9641cc7e5bd5251a70e347c22bb8d55
- Adjust comments in inventory, trivial change (James McCarthy)  
- After upgrade nova_data still runs (Vladislav Belogrudov)  
- After upgrade old ceilometer containers are left (Vladislav Belogrudov)  
- After upgrade computes cannot ssh into each other (Vladislav Belogrudov)  
- Containerized sshd does not work with older PAM (Vladislav Belogrudov)  
- Bug 25254426 - Import Oracle Db and SQL database library packages into Murano catalog during OpenStack deployment. (ellen)  
- Remove global augment setting (Mick Thompson)  
- Removed dnsmasq_dhcp_mtu definition from spec file (Mick Thompson)

* Fri Dec 16 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-223.el7
- BUILDINFO: commit=7079ea796d99192c0025db884dd8edb5bae4f038
- Normal users cannot use Swift (Vladislav Belogrudov)

* Thu Dec 15 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-222.el7
- BUILDINFO: commit=be92a63c72137fdf182f183f522c5e25f4f7bf13
- Clone openstack-oracle-murano-apps as part of build (Paul Bourke)

* Thu Dec 15 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-221.el7
- BUILDINFO: commit=dffeee7949d5c1fc4428d1e23c67204855b7001d
- Add separate user/password/vhost for murano agents (Vladislav Belogrudov)

* Thu Dec 15 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-220.el7
- BUILDINFO: commit=bac727f4a1dc8785c641c88b0f3bd03c074db157
- Fix missing bracket for ceilometer default address (Vladislav Belogrudov)

* Thu Dec 15 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-219.el7
- BUILDINFO: commit=467f851a15e8eada7d0a3dc69f8f51e357d2a5c1
- More fixes for murano zip plugins (Paul Bourke)

* Thu Dec 15 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-218.el7
- BUILDINFO: commit=14baf324197f677dca303351a8f88127f3c6c636
- Ceilometer - fix use of local api_interface var (Vladislav Belogrudov)

* Thu Dec 15 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-217.el7
- BUILDINFO: commit=4345b2f4de5d473553730820bd685265dce88d6a
- Rabbits deploy fail if controlers nic names differ (Vladislav Belogrudov)

* Wed Dec 14 2016 Wiekus Beukes <vinkman100@gmail.com> - 3.0.1-216.el7
- BUILDINFO: commit=9ad7348a3841da9eb631a210cba4626fbdfe3b93
- Removed the bad -e piece from sed (Wiekus Beukes)

* Wed Dec 14 2016 Wiekus Beukes <vinkman100@gmail.com> - 3.0.1-215.el7
- BUILDINFO: commit=6b0670c3b8e8dd68cf395243cf08ed6a33659f8b
- Fix Murano command (Wiekus Beukes)

* Wed Dec 14 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-214.el7
- BUILDINFO: commit=351f1eedaa590cd4bcc76a8d7380a7e57571e65f
- Move murano packages to base image override (Paul Bourke)

* Wed Dec 14 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-213.el7
- BUILDINFO: commit=6c03bcd3213d735fef3db54c3b3f83c7ea2b85d4
- Fix typo in .spec file (Kevin Loughnane)

* Wed Dec 14 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-212.el7
- BUILDINFO: commit=c1c21cd39eb8872380c1d455e6b27ed9c7eb5b1d
- Changed MTU setting for dnsmasq with vxlan (Mick Thompson)

* Wed Dec 14 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-211.el7
- BUILDINFO: commit=1d7e24aed11b7896de5ee4f6344f65edf6a0ad49
- Restart libvirtd using service command (Mick Thompson)

* Wed Dec 14 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-210.el7
- BUILDINFO: commit=41bcebb2b4a634356254e08c51e6b9b5fe9c7476
- Split nova upgrade workaround between pre and post (Mick Thompson)

* Wed Dec 14 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-209.el7
- BUILDINFO: commit=6274c6d1b2a232a4e2663fb94c8680fafd204132
- Revert "Split nova upgrade workaround between pre and post" (Mick Thompson)

* Wed Dec 14 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-208.el7
- BUILDINFO: commit=a513ff4d57b44770e432cdd4fe97426794937795
- Automatically restart libvirtd after OSD deploy on OVM-S (Mick Thompson)

* Wed Dec 14 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-207.el7
- BUILDINFO: commit=98e5f3304baa42653a7334b3bff089a2013d9446
- Fix incorrect reference to host local vars (Nikita Gerasimov)

* Wed Dec 14 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-206.el7
- BUILDINFO: commit=6fb252b7243b217fd0ff533dfcf35a37b4a8e5e2
- Re-import Murano core library on upgrade (Vladislav Belogrudov)

* Tue Dec 13 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-205.el7
- BUILDINFO: commit=97f9a4758b8a023206d4a5371f46021ad5887b4b
- Added missing brackets to nova.conf check in openstack-kolla.spec file (Mick Thompson)

* Tue Dec 13 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-204.el7
- BUILDINFO: commit=787959470d19cb41aefdedeb0335b025665e4ef6
- Split nova upgrade workaround between pre and post (Mick Thompson)

* Tue Dec 13 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-203.el7
- BUILDINFO: commit=c1d58140b261686959725fb4cf5a7a5e5b3e3ea1
- Tokenise mtu in dnsmasq.conf.j2 (Paul Bourke)

* Tue Dec 13 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-202.el7
- BUILDINFO: commit=a6b85037c094bfa916d27512599efdcceacda3f5
- Add internal mirrors for vpnaas (Paul Bourke)

* Tue Dec 13 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-201.el7
- BUILDINFO: commit=4a818ae525807707a23c9beca44da5ecb441ed74
- Include OracleDb apps in murano-engine (Paul Bourke)

* Tue Dec 13 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-200.el7
- BUILDINFO: commit=69b6e628c0d9a8e4aa66d87f9440e330004c1826
- Workaround for nova upgrade from 2.1.1 to 3.0.1 (Mick Thompson)

* Mon Dec 12 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-199.el7
- BUILDINFO: commit=cb6a2a12c8f08ab4924dac31ef400fb3bc8c96b9
- Set enable_aodh if ceilometer is enabled in 2.1.1 (Mick Thompson)

* Mon Dec 12 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-198.el7
- BUILDINFO: commit=2c7afa61c861610956e1f7672b79a0ee4b5ea46f
- Mark the nova.conf augment file as a config file (James McCarthy)

* Mon Dec 12 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-197.el7
- BUILDINFO: commit=6fb60195fda87d34797742b31806f3829d185eeb
- Set internal sources for neutron-sfc & nova-spice (Paul Bourke)  
- Remove source install type for novnc / spice (Paul Bourke)  
- Increase timeout for RabbitMQ in HAProxy (Vladislav Belogrudov)

* Mon Dec 12 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-196.el7
- BUILDINFO: commit=e13dbe1404c06bfc963de66612aeb825a6c04fa2
- Murano agents access RabbitMQ via external FQDN (Vladislav Belogrudov)

* Mon Dec 12 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-195.el7
- BUILDINFO: commit=80687c1a4b0b3082f3bf12f0d8b1e7f7e020a6d2
- Re-introduce nova.conf placeholder augment file (James McCarthy)

* Mon Dec 12 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-194.el7
- BUILDINFO: commit=110f18675398bdda6fc9ce6fa7e9cba3098b9ce5
- Clear the yum cache after uninstalling ceph-common (Murali Annamneni)

* Sat Dec 10 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-193.el7
- BUILDINFO: commit=55178ce4e53facc1fe2aa62ba70b3f0ff2dfb14f
- Fix lvm driver target address (Vladislav Belogrudov)

* Sat Dec 10 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-192.el7
- BUILDINFO: commit=f38a7ef41baf3a861491ea773bc5229036763a2b
- Fix lvm driver/backend name backward compatibility (Vladislav Belogrudov)

* Sat Dec 10 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-191.el7
- BUILDINFO: commit=9e0be58eec94d42f970ff2b01753e19138285236
- Auto create nova.conf augment on upgrade (with updated changelog) (James McCarthy)

* Thu Dec 08 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-190.el7
- BUILDINFO: commit=facf7e8925f80c43134724739c7359c262bc53cf
- Adjust sequence for mysqlcluster upgrade (James McCarthy)

* Thu Dec 08 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-189.el7
- BUILDINFO: commit=197c56e4bb85f284561d3c3df0f5312234d233f4
- Revert "Auto create nova.conf augment on upgrade" (James McCarthy)

* Thu Dec 08 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-188.el7
- BUILDINFO: commit=3057a8484fd5d303624b9752dfc832f9e73a774f
- Auto create nova.conf augment on upgrade (James McCarthy)

* Wed Dec 07 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-187.el7
- BUILDINFO: commit=b096b25ef6b10d3fbbde8606469fdcd16d5512f8
- Adjust sequence for mysqlcluster upgrade (James McCarthy)

* Wed Dec 07 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-186.el7
- BUILDINFO: commit=38a638669ca23077392ac52560911468794f5bf7
- neutron-agents run on 'neutron-l3-agents' hosts (Vladislav Belogrudov)

* Wed Dec 07 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-185.el7
- BUILDINFO: commit=b0417d6ea2b5767062bee6e325ca505eeca32b19
- On upgrade remove mysqlcluster_data containers (James McCarthy)

* Wed Dec 07 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-184.el7
- BUILDINFO: commit=487cf393eb33406405153a210976882f31cee006
- On upgrade remove kolla_ansible containers (James McCarthy)

* Wed Dec 07 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-183.el7
- BUILDINFO: commit=8b816ace5f1b78efb14bfb8d5b1fce9ec78b0c6e
- Adjust sequence for mysqlcluster upgrade (James McCarthy)

* Tue Dec 06 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-182.el7
- BUILDINFO: commit=361187c3d7ac7fd17ae0b0678108622ef9e6ce33
- On upgrade remove nova_iscsid and nova_multipath containers (James McCarthy)

* Tue Dec 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-181.el7
- BUILDINFO: commit=1fbfa320c61b680826cfdd1fa460c6d183be2362
- Swift data transfer should not be using the API Network (James McCarthy)

* Tue Dec 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-180.el7
- BUILDINFO: commit=fef06d4bfd4c5b53decb9c6529bbcb76171e4133
- Swift data transfer should not be using the API Network (James McCarthy)

* Tue Dec 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-179.el7
- BUILDINFO: commit=ed7b0642bdc8b654c0072eed26cfb00dd35f1439
- Auto create nova.conf augment on upgrade (James McCarthy)

* Tue Dec 06 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-178.el7
- BUILDINFO: commit=eaea0f2c633a461ece2325ead8fc3df5f28f2691
- Check if new password file is installed as rpmnew (Vladislav Belogrudov)

* Mon Dec 05 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-177.el7
- BUILDINFO: commit=f525c261a5f0084095275209e2d3bf97a3d97f44
- Revert ""mv" old passwords instead of "cp" to avoid .rpmnew" (Vladislav Belogrudov)

* Mon Dec 05 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-176.el7
- BUILDINFO: commit=89ef508d4a2fa14fba373621bc95f6a2c60acc59
- Remove neutron-agents containers on upgrade (Vladislav Belogrudov)  
- Sometimes merging of passwords.yml gives json (Vladislav Belogrudov)  
- "mv" old passwords instead of "cp" to avoid .rpmnew (Vladislav Belogrudov)

* Fri Dec 02 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-175.el7
- BUILDINFO: commit=2c4b1d4282120e4319ffb049ce5236195cf55569
- Auto create nova.conf augment on upgrade (James McCarthy)

* Fri Dec 02 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-174.el7
- BUILDINFO: commit=d823915519dd3e3d09df14eb45d30fdb5ed9f5e6
- Add missing per service Keystone config augments (Paul Bourke)

* Fri Dec 02 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-173.el7
- BUILDINFO: commit=fc549154239b177dad36e986ff9aa47fc83912fe
- Update temp location for magnum-ui (Paul Bourke)

* Fri Dec 02 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-172.el7
- BUILDINFO: commit=71ccd9721c1c0de143ffa56e58efeaf81ed9ea5a
- Auto create nova.conf augment on upgrade (James McCarthy)

* Fri Dec 02 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-171.el7
- BUILDINFO: commit=7651ce6748760d81efcb29cf8d12df42235823c1
- OpenStack Services Should Use keystone_internal_url for auth (Dave McCowan)  
- Update O3L build configs for new services (Paul Bourke)  
- Enable magnum dashboard when enable_magnum is yes (Paul Bourke)  
- Install magnum dashboard into the horizon image (Paul Bourke)  
- Enable ironic ui when enable_ironic is yes (Jeffrey Zhang)  
- Add ironic-ui to horizon image (Jeffrey Zhang)

* Fri Dec 02 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-170.el7
- BUILDINFO: commit=6c78cb21a661bdfb786bfcb60bc07fdc5947a656
- Fix neutron lbaas dashboard (Jeffrey Zhang)  
- Run collect static during container startup when necessarily (Jeffrey Zhang)

* Fri Dec 02 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-169.el7
- BUILDINFO: commit=92fb9c46f4d816cded84ced1eb8a567825e0776b
- Drop ceilometer database and re-bootstrap (Mick Thompson)

* Thu Dec 01 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-168.el7
- BUILDINFO: commit=9deacf91e5701e03a17486d0a9a5f5fded88da2c
- Run virt_type_checker on all nodes types during precheck (Paul Bourke)

* Thu Dec 01 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-167.el7
- BUILDINFO: commit=59ca801b080fd76a12f99622454aa0a6a3780d86
- Fix docker start issue (Vladislav Belogrudov)

* Thu Dec 01 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-166.el7
- BUILDINFO: commit=d50dec6201d7404bbba0b1a9f1e174a7e9339be0
- External cloud address backward compatibility (Vladislav Belogrudov)

* Thu Dec 01 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-165.el7
- BUILDINFO: commit=2700113006153876b92438d06ba4992f675aad88
- Revert "Change username in nova.conf template to match 2.1.1." (James McCarthy)

* Thu Dec 01 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-164.el7
- BUILDINFO: commit=7e276caa52c2a9a355f7b19dd21bc182939c76cd
- Attempt to stop ceilometer containers before haproxy upgrade (James McCarthy)

* Wed Nov 30 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-163.el7
- BUILDINFO: commit=7a7b2f6208d9bd9dd72f73ecbc824e9d6fe8e791
- During upgrade neutron-servers must be down (Vladislav Belogrudov)

* Wed Nov 30 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-162.el7
- BUILDINFO: commit=3dfe85d5ccadc4a4ae31d0ab782604ff0e4586d2
- Stop ceilometer containers before haproxy upgrade (Vladislav Belogrudov)

* Wed Nov 30 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-161.el7
- BUILDINFO: commit=c598fa7eb29ff7e878cfc70b815eee2f58dba3b2
- Re-add qemu-img to nova-compute (Kevin Loughnane)

* Wed Nov 30 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-160.el7
- BUILDINFO: commit=792a31807a29376106562602e6aef629c5e35b9a
- Revert "Reorder of tasks for deploy versus upgrade" (Vladislav Belogrudov)

* Wed Nov 30 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-159.el7
- BUILDINFO: commit=72b190d548717172bba3b0ab9ca234aed66d84f6
- Revert "Move HAProxy earlier in the Upgrade list" (Vladislav Belogrudov)

* Tue Nov 29 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-158.el7
- BUILDINFO: commit=8797548167d2d8d01dee41d5a8b527a7bae12950
- Add bootstrap for rabbitmq upgrades. (James McCarthy)

* Tue Nov 29 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-157.el7
- BUILDINFO: commit=731e4fa0d396e541104710541022c9355780f678
- Fix defaults for cinder override values in rpm (Paul Bourke)

* Tue Nov 29 2016 Murali Annamneni <murali.annamneni@oracle.com> - 3.0.1-156.el7
- BUILDINFO: commit=61147bb034d6a8bdc8bd759e6768c75a38d61c3d
- Merge old and new passwords.yml  after kolla-ansible  install/update (Murali Annamneni)

* Tue Nov 29 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-155.el7
- BUILDINFO: commit=c2a449787218d1586b09e0dfd1ff7fb6f91f8517
- Fix RPM build by including ./kolla/cmd/mergepwd.py and kolla-mergepwd (Kevin Loughnane)  
- Downgrade ceph-common in nova-compute from latest to 0.80.7-3 (Murali Annamneni)  
- Move HAProxy earlier in the Upgrade list (Mick Thompson)  
- Update Cinder defaults for O3L (Paul Bourke)  
- Treat aodh upgrade as deploy (Mick Thompson)  
- Add tool to merge passwords during release upgrade (Vladislav Belogrudov)

* Mon Nov 28 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-154.el7
- BUILDINFO: commit=67d02223746bc025cfead75599dade02cef2d6e9
- Increase HAProxy MySQL Cluster socket timeouts to 1 hour. (Kevin Loughnane)  
- Revert "Stop configuring neutron to enforce DHCP MTU option" (James McCarthy)

* Mon Nov 28 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-153.el7
- BUILDINFO: commit=4a19c2a74437b2a7d1fa635e7d092812fa5fb045
- Change username in nova.conf template to match 2.1.1. (James McCarthy)

* Fri Nov 25 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-152.el7
- BUILDINFO: commit=c93f106825009ed6b886fe77feecaa35411841e1
- Ignore dom0 qemu processes during destroy (Borne Mace)

* Fri Nov 25 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-151.el7
- BUILDINFO: commit=00afb08d1133c3a59e75bddf64027b5c24c7787a
- Allow nova_compute & nova_compute_ironic together (Paul Bourke)

* Thu Nov 24 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-150.el7
- BUILDINFO: commit=e287a0d1fa9a2b4bf52650d64cff092cc8d4677b
- Fixed deployment failures when keystone_fernet enabled (Murali)  
- Adding strongswan/openswan to source branch of neutron-vpnaas-agent (Chao Guo)  
- Add neutron vpnaas code into neutron-server container (Jeffrey Zhang)

* Thu Nov 24 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-149.el7
- BUILDINFO: commit=899ee1ded0e2eac31ecd0a3b82d9b801046d0b82
- Add missing pull task for neutron-vpnaas-agent (Paul Bourke)  
- neutron-vpnaas cannot run as root for redhat derivatives (Paul Bourke)  
- Fix neutron-vpnaas for redhat derived bases (Paul Bourke)  
- Add fwaas_driver.ini file to neutron-vpnaas-agent container (Christian Berendt)

* Thu Nov 24 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-148.el7
- BUILDINFO: commit=c97db878dcffc1ec6ab485f19fdd0e7289b053c4
- Add max_allowed_packet parameter to my.cnf (Mick Thompson)

* Wed Nov 23 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-147.el7
- BUILDINFO: commit=0db5a55f79e0bbf006728fff808419d6d3286092
- Alias ceilometer_database_type to ceilometer_database_backend. (James McCarthy)

* Wed Nov 23 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-146.el7
- BUILDINFO: commit=c0d7e77633b8e4ed37437fc71e3e3780df1214b1
- Revert "Ignore dom0 qemu processes during destroy" (Borne Mace)

* Wed Nov 23 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-145.el7
- BUILDINFO: commit=f6109eeb94c4b28c1c7339792a6d46b7efe832b2
- Added check for NDB Nodegroup (Mick Thompson)

* Wed Nov 23 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-144.el7
- BUILDINFO: commit=0a79139907c555d33eaf420b713d5fb9111856c9
- Ceilometer cannot use external mongodb (Vladislav Belogrudov)

* Wed Nov 23 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-143.el7
- BUILDINFO: commit=01ae59a4c8ed29e569037c2fd5bdbb2e37d52d79
- Fix default of ceilometer_database_mongodb_address (Vladislav Belogrudov)

* Wed Nov 23 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-142.el7
- BUILDINFO: commit=a6d1d4e859fdb3cd3eff9b316269c50ae78431a0
- Corrects typo "mondodb_port" in ceilometer (Farid Da Encarnacao)

* Wed Nov 23 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-141.el7
- BUILDINFO: commit=99449b418b6a7703df06392b4d4cb1d615ffa03c
- Fix cinder-backup configuration for swift backend (Vladislav Belogrudov)

* Tue Nov 22 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-140.el7
- BUILDINFO: commit=ac7bf122ddefda77a65cda9a876107532c79ce8a
- Fix keystone fernet file exchange via ssh (Christian Berendt)

* Tue Nov 22 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-139.el7
- BUILDINFO: commit=e47465234a0a2f60872e392d021282c180cec8c2
- Enable neutron-lbaas in the o3l build (Paul Bourke)

* Tue Nov 22 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-138.el7
- BUILDINFO: commit=515702d0010bb61310d56f138da767e7da836677
- Move back to using external PyPI for the time-being (Kevin Loughnane)

* Tue Nov 22 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-137.el7
- BUILDINFO: commit=80a57eee89d5cf21adc8053d4fe4552927cf9c6f
- Use internal Pypi mirror for builds (Kevin Loughnane)

* Mon Nov 21 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-136.el7
- BUILDINFO: commit=bee690493d96d79aa270ff832919b7fa28a371cc
- Use kolla_internal_vip_address for glance_api servers (Vladislav Belogrudov)  
- Add ironic-inspector to o3l kolla-build.conf (Paul Bourke)  
- Fix invalid json in ironic service (Jeffrey Zhang)  
- fix config file permission to ironic instead of root (Waldemar Znoinski)  
- Install the packages needed by different ironic drivers (Jeffrey Zhang)  
- copy ldlinux.c32 to /tftpboot in ironic_pxe (Waldemar Znoinski)  
- Add hexdump package for ironic-conductor container (Jeffrey Zhang)  
- install pxelinux for ironic_pxe (Waldemar Znoinski)  
- Fix ironic failed (Jeffrey Zhang)  
- install iptables in ironic-inspector container (Waldemar Znoinski)

* Mon Nov 21 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-135.el7
- BUILDINFO: commit=3b5178dbda4a241aafc07139d7b1ad9b0e50e256
- fix ironic-inspector setup (Waldemar Znoinski)  
- Fix ironic Dockerfile (caowei)  
- install ironic-inspector during image build (Waldemar Znoinski)

* Fri Nov 18 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-134.el7
- BUILDINFO: commit=c108d7b4952c9809ffedd080435c60408ee017e5
- Ignore dom0 qemu processes during destroy (Borne Mace)

* Fri Nov 18 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-133.el7
- BUILDINFO: commit=8f31f9c16eba428809607aaefa3dfde2e64ceff5
- Set mysqlcluster-base verison to 7.4.13-1 (Mick Thompson)

* Fri Nov 18 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-132.el7
- BUILDINFO: commit=8a177babd7472dd3c14984db9417e532bd873b1a
- Fix cinder-backup backend names and logic (Vladislav Belogrudov)

* Fri Nov 18 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-131.el7
- BUILDINFO: commit=9ac5c240feb055febeb62b4b75a965d6ef112b0c
- Use /etc/iscsi/ Host-bindmount for Cinder Backup (Kevin Loughnane)

* Fri Nov 18 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-130.el7
- BUILDINFO: commit=6f0e365e996b1095f598401d6697c93221726d14
- iscsi role misses 'storage' group (Vladislav Belogrudov)

* Thu Nov 17 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-129.el7
- BUILDINFO: commit=f3df0257fa7878fbe1ec1e220ae0c94d9781150d
- Cinder-backup fails while backing up iSCSI volumes (Vladislav Belogrudov)

* Thu Nov 17 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-124.el7
- BUILDINFO: commit=85e6ffb28aeb400bae3a5cbef4380e0a6ec18cca
- Copy nova ssh credentials with correct owner (Vladislav Belogrudov)

* Thu Nov 17 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-123.el7
- BUILDINFO: commit=94dc0600aefc8c072db10aca0d8dc8006ea50b8b
- Set OS_PROJECT_DOMAIN_NAME and OS_USER_DOMAIN_NAME env vars in docker-ostk (Kevin Loughnane)

* Wed Nov 16 2016 Wiekus Beukes <wbeukes@wiekusmb.private.home> - 3.0.1-122.el7
- BUILDINFO: commit=96fab187f4612841b3f01c8cfe663fc21ebaa205
- Save the old passwords file (Wiekus Beukes)

* Wed Nov 16 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-121.el7
- BUILDINFO: commit=66e2ee2638a04949cd675b1901c013eaa16d992e
- Added missing stop playbook (Borne Mace)

* Wed Nov 16 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-120.el7
- BUILDINFO: commit=c48c2552f2ad9e71ad6b0d47770a33ce5e98094a
- Reorder of tasks for deploy versus upgrade (Mick Thompson)

* Wed Nov 16 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-119.el7
- BUILDINFO: commit=ab568f2b5048939173dbd26444c20d9b436f6993
- Create the nova instances directory when need during starting (Jeffrey Zhang)

* Wed Nov 16 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-118.el7
- BUILDINFO: commit=66ede38126b3c221754aea70477036876a2e7ed5
- Fix fact gathering when using --limit (Paul Bourke)

* Tue Nov 15 2016 Wiekus Beukes <wbeukes@wiekusmb.private.home> - 3.0.1-117.el7
- BUILDINFO: commit=b6daa90731b3763eb6c10da65174832a2f48e593
- Mark password.yml as a config file (Wiekus Beukes)  
- Update ml2_conf.ini.j2 for vlan and multiple external/public networks. (James McCarthy)

* Tue Nov 15 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-116.el7
- BUILDINFO: commit=9e1321f51d2cf8589e0e0663a94faf798228243b
- Update ml2_config.ini j2 template for vxlan. (James McCarthy)  
- fix horizon fernet container (Jeffrey Zhang)

* Mon Nov 14 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-115.el7
- BUILDINFO: commit=c65c944fa1db4753de3c929c02bd99b122015f87
- Fix location of systemctl (Vladislav Belogrudov)

* Fri Nov 11 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-114.el7
- BUILDINFO: commit=6b2bc4292c54b207174aeff1e2231510b8671cb8
- Update O3L Ceph packages to use official repo (Paul Bourke)

* Fri Nov 11 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-113.el7
- BUILDINFO: commit=33918d4c9dd93d58ab3af580792f3bfbaae7ef30
- Update the default base_tag setting. (James McCarthy)

* Fri Nov 11 2016 Wiekus Beukes <wbeukes@wiekusmb.private.home> - 3.0.1-112.el7
- BUILDINFO: commit=040c5f3372d450e89ad0da722732a64459c11829
- Added quotes to fix escape in cat (Wiekus Beukes)

* Thu Nov 10 2016 Wiekus Beukes <wbeukes@wiekusmb.private.home> - 3.0.1-111.el7
- BUILDINFO: commit=556902961e2c8b6885872408044dc90ce4abf35a
- Fixed syntax errors in post (Wiekus Beukes)

* Thu Nov 10 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-110.el7
- BUILDINFO: commit=5665328e47f2e2297c00a13f7978410571cbb6b0
- Wrap systemctl command to avoid execution on ovm nodes. (James McCarthy)

* Thu Nov 10 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-109.el7
- BUILDINFO: commit=3d9d28af89d8d6662774ec5a5e3f7ac804b0e6c3
- Exclude port from ceilometer_database_mysql_address (Vladislav Belogrudov)

* Thu Nov 10 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-108.el7
- BUILDINFO: commit=bbcebc203dfc9983929e550310748de113425353
- Add more options for cinder-backup. (James McCarthy)  
- Fix file owner for nova ssh keys (Vladislav Belogrudov)

* Thu Nov 10 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-107.el7
- BUILDINFO: commit=7dcf351129271b7bbdb7ebae50c8e31d5670e845
- Add default for ceilometer_database_address (Vladislav Belogrudov)

* Thu Nov 10 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-106.el7
- BUILDINFO: commit=314f612afb7048ae12314280d769ead580ddb932
- Bug 25070585:  Update the minimum docker-engine version to 1.12.0 (Kevin Loughnane)

* Thu Nov 10 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-105.el7
- BUILDINFO: commit=96ea6e027904e11728b43ee7e113b5ec72e7cee8
- Add local_ip entry back in for ovs in ml2_conf.ini.j2 template. (James McCarthy)

* Wed Nov 09 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-104.el7
- BUILDINFO: commit=755d4c7e1d92c8f2c68ccb80aaa7401c9c70129a
- Missing customization of tenant network (James McCarthy)

* Wed Nov 09 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-103.el7
- BUILDINFO: commit=2cb31c255783ab157b4f1a51f8d4338f7f87bf49
- Revert "Missing customization of tenant network" (James McCarthy)  
- Nova cannot resize or migrate instances - no keys (Vladislav Belogrudov)

* Wed Nov 09 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-102.el7
- BUILDINFO: commit=3f519fc862f17611950a5d404bf9a75cc5a401cc
- Predeploy fails if RabbitMQ hostnames are absent (Vladislav Belogrudov)

* Tue Nov 08 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-101.el7
- BUILDINFO: commit=210007bf5eb7305eb741fac6c225ad47bc1cdeeb
- Missing customization of tenant network (James McCarthy)  
- Set more internal repos in kolla-build.conf (Paul Bourke)  
- Install neutron-lbaas in neutron-server (Paul Bourke)  
- Allow neutron-fwaas to be enabled in Neutron (Paul Bourke)  
- Fix plugin parsing for base images (Paul Bourke)  
- Install neutron-lbaas-dashboard from source in horizon container (Christian Berendt)  
- Remove duplicate lbaas provider config (liyingjun)  
- Fix vpnaas for neutron (liyingjun)

* Tue Nov 08 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-100.el7
- BUILDINFO: commit=6b905453287dd71e3069be9048f2622218bf9295
- Integrate neutron-vpnaas-agent into the neutron Ansible role (Christian Berendt)  
- Add neutron-vpnaas-agent container (Christian Berendt)

* Tue Nov 08 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-99.el7
- BUILDINFO: commit=7fde9a71f13aef45e3c40f2c7e3fc24cd9cf78be
- Update use_udev_checker logic for non-ovm case. (James McCarthy)

* Mon Nov 07 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-98.el7
- BUILDINFO: commit=00b33fc311e618291a5b9affc99f24c2f2127e16
- Add backward compatibility for ceilometer_database_address (Vladislav Belogrudov)

* Mon Nov 07 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-97.el7
- BUILDINFO: commit=7b8e421062f52ce82f0ce75ed69b3c41efa65e5b
- Added 'glance_backend_file=yes' to the spec file (Murali Annamneni)  
- Allow flexibility in mysql backend for ceilometer (Vladislav Belogrudov)  
- Include oslo.vmware along with other oslo packages in openstack-base. (James McCarthy)

* Fri Nov 04 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-96.el7
- BUILDINFO: commit=dae9d133ccf38424f8aea87a5e285c3f27ddf04b
- Update the cleanup-host script for swift cleanup. (James McCarthy)  
- Add automatic use_udev_checker for ceph. (James McCarthy)

* Thu Nov 03 2016 Murali Annamneni <murali.annamneni@oracle.com> - 3.0.1-95.el7
- BUILDINFO: commit=e6ff648352e0051d92e9cc5e94333d76ec093266
- Added 'post-41' option to enable support for post MySQL v4.1client compatible checks (Murali Annamneni)  
- Update prechecks port_checks task, remove some checks. (James McCarthy)

* Wed Nov 02 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-94.el7
- BUILDINFO: commit=f835c9b19bbb86ba9801ab7d6487b7df9ceed5d4
- Added inclusion of stop-containers script in rpm (Borne Mace)  
- Check api_interface instead of network_interface (Vladislav Belogrudov)

* Wed Nov 02 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-93.el7
- BUILDINFO: commit=a494b051bd193ca4104520ceaf355943e1fb1433
- Enable elasticsearch/kibana by default for O3L (Paul Bourke)

* Tue Nov 01 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-92.el7
- BUILDINFO: commit=60863e4a33ed319bf1bbe8c4a3e9b7b4c4e33f05
- Added support for a stop playbook in kolla (Borne Mace)

* Fri Oct 28 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-91.el7
- BUILDINFO: commit=4c1bb320e54735682017bc16fbcf82eb906473b3
- Adjust object-replicator heading within object.conf.j2 template. (James McCarthy)

* Fri Oct 28 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-90.el7
- BUILDINFO: commit=1e577181c95672d99a89a23336e8d77f1c7e7b0d
- Add dosfstools package to Nova, needed by OVM Server ComputeNode (Kevin Loughnane)

* Fri Oct 28 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-89.el7
- BUILDINFO: commit=65552b1d4ae6e04956d2d9be1b8bd308c15fd2ca
- Include os-client-config sed operation in kolla-toolbox. (James McCarthy)

* Fri Oct 28 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-88.el7
- BUILDINFO: commit=d404d0b1c09dcb64630eba4601d885fa27fd89a8
- Update overrides for certain clients (James McCarthy)

* Fri Oct 28 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-87.el7
- BUILDINFO: commit=b86d820238b777793f3066b3e88e11c30f9defd9
- Unpin troveclient in template-overrides. (James McCarthy)

* Thu Oct 27 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-86.el7
- BUILDINFO: commit=f1a3f1255c9e82315b062c665d34d304b52d0b51
- Ensure mount for /run/netns will be shared for OVM (James McCarthy)  
- Update shade for the kolla-toolbox (James McCarthy)

* Thu Oct 27 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-85.el7
- BUILDINFO: commit=8c9d6ab70ece712fb1b2194ec017650a82068126
- Ensure mount for /run/netns will be shared for OVM. (James McCarthy)

* Mon Oct 24 2016 Sercan Acar <sercan.acar@oracle.com> - 3.0.1-84.el7
- BUILDINFO: commit=8bea811f55d196aebdeae722bd2024d68c700199
- Haproxy config fails to copy due to typo (Sercan Acar)

* Mon Oct 24 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-83.el7
- BUILDINFO: commit=9448162668fa81e8c67f8ffa8277bb6ab6dbcaae
- Added 'listen rabbitmq' to haproxy.cfg.j2 (Mick Thompson)

* Fri Oct 21 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-82.el7
- BUILDINFO: commit=4695d5b8992b11123c43305ce944ad0b1d34b24c
- Disable get-pip.py in kolla-toolbox for O3L (Paul Bourke)  
- Allow operators to customise pip in kolla-toolbox (Paul Bourke)

* Fri Oct 21 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-81.el7
- BUILDINFO: commit=dc75898b91be4fae2112f06100640d4c108fae1c
- Change mysql-check in HAProxy to post MySQL 4.1 (Nikita Gerasimov)

* Thu Oct 20 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-80.el7
- BUILDINFO: commit=f8512b05936a62cd3e9fa4e5a407106ce7934bb8
- Predeploy fails if RabbitMQ hostnames are absent (Vladislav Belogrudov)

* Thu Oct 20 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-79.el7
- BUILDINFO: commit=0d8c885be19bc5483225c9ef01a2a6e55215cd33
- Install python clients in kolla-toolbox for O3L (Paul Bourke)

* Thu Oct 20 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-78.el7
- BUILDINFO: commit=ab6ee77ee686a0b768522c895993d654f649922c
- Allow operators to use 'fallback mode' for Ceph disks (Paul Bourke)

* Thu Oct 20 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-77.el7
- BUILDINFO: commit=d1ca1a2486a27919e4a7b41dfe4566c741d6d36d
- Ceilometer cannot create standalone mysql database (Vladislav Belogrudov)

* Thu Oct 20 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-76.el7
- BUILDINFO: commit=2e6db8c0a49dedd29095ca2c2b1cff35e24c3fe6
- Murano fails to deploy - cannot check core library (Vladislav Belogrudov)  
- Revert "Version check for udev is too low" (Paul Bourke)

* Mon Oct 17 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-75.el7
- BUILDINFO: commit=c7d19d486ae7a1273a9ca1d1d0b59805d078cce3
- Remove sudo in destroy scripts (Paul Bourke)

* Mon Oct 17 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-74.el7
- BUILDINFO: commit=8d6ca1314cfb060a5f6c03e3e6fe49d3a339e1be
- Adding parameter mysqlcluster_connect_timeout and setting default value (Mark Duggan)

* Fri Oct 14 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-73.el7
- BUILDINFO: commit=60e1a9f9744811ac75ca6d278d89b44ebeec3295
- RabbitMQ cluster should work on api interface (Vladislav Belogrudov)

* Fri Oct 14 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-72.el7
- BUILDINFO: commit=349c3ac12800c9fa1b168337d581e12972b97f5d
- Remove indentation from l3_agent.ini.j2 (James McCarthy)

* Fri Oct 14 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-71.el7
- BUILDINFO: commit=56a60e016e957bee9dc2bbdc435f9c5495da27a7
- Enable murano by default in all.yml (Mark Duggan)

* Fri Oct 14 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-70.el7
- BUILDINFO: commit=042a1099f47cb4962741a036d59cd975532a4332
- Loads the configfs module upon RPM install (Mark Duggan)

* Thu Oct 13 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-69.el7
- BUILDINFO: commit=51057f9192ebe7c7834cb9c53b9a59f9c825d6e9
- Setting default value for cinder_iscssi_helper to lioadm (Mark Duggan)

* Thu Oct 13 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-68.el7
- BUILDINFO: commit=aeaac429419ed885fb5205523cd8a2f91fe3dead
- Unmount Ceph OSD disks as part of destroy (Paul Bourke)

* Thu Oct 13 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-67.el7
- BUILDINFO: commit=186a0641c245c688d78b914031a4e82048e8db61
- Prechecks fail if using separate api interface (Vladislav Belogrudov)

* Thu Oct 13 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-66.el7
- BUILDINFO: commit=b52f40ea3a88ac87e3aca1ced05784b94c0dbc5e
- precheck fails due to unknown cinder_volume_group (Vladislav Belogrudov)

* Thu Oct 13 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-65.el7
- BUILDINFO: commit=f7eb194d7d86adbbc9b462a13f0a8da082abb13b
- Ensure enable_multipathd is enabled as part of Oracle defaults. (James McCarthy)

* Thu Oct 13 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-64.el7
- BUILDINFO: commit=2e5850f2895ef68feb5cfb2cb0ddacff020e5f72
- Parameterising iscsi_helper and setting default value (Mark Duggan)

* Thu Oct 13 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-63.el7
- BUILDINFO: commit=025645d9ff826d04cbb484dc95c6a029ecea05bc
- Set ceilometer_database_type mysql for O3L (buildrpm) (Paul Bourke)

* Thu Oct 13 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-62.el7
- BUILDINFO: commit=8fa4e4eeb286f492927454435e0e7fb6cac8c961
- Exclude template-overrides.j2 from openstack-kolla-ansible (Mick Thompson)

* Wed Oct 12 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-61.el7
- BUILDINFO: commit=b084bd29b6a0c6b52bd9fb6b08bd759051bded3a
- Add register to upgrade.yml to create correct endpoint (Mick Thompson)

* Wed Oct 12 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-60.el7
- BUILDINFO: commit=af95776945118ea2b6895c3f28415a2ee39b3b6c
- Disable nova_hw_disk_discard for O3L (buildrpm) (Paul Bourke)  
- Allow operators to change hw_disk_discard in Nova (Paul Bourke)

* Wed Oct 12 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 3.0.1-59.el7
- BUILDINFO: commit=37eb2ea7b08c243c05b263fb5b2159c1c292209e
- Template overrides for o3l elasticsearch & kibana (Paul Bourke)

* Tue Oct 11 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-58.el7
- BUILDINFO: commit=c8ec4d57f80dc377cdeabd4cef877b077b88967a
- Added ansible destroy scripts into rpm (Borne Mace)  
- Added missing cleanup-images in setup.cfg (Borne Mace)

* Tue Oct 11 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-57.el7
- BUILDINFO: commit=c5b4a28ac29db8904bc92f64da1a1f25e2c51c93
- cinder deploy fails due to non-existing tgtd group (Vladislav Belogrudov)

* Tue Oct 11 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-56.el7
- BUILDINFO: commit=95e6d9b320a0cb7a5e5a1447a0cf254f93bbb941
- Fix bad cherry-pick in ml2_conf.ini.j2 (Paul Bourke)  
- Version check for udev is too low (Paul Bourke)

* Mon Oct 10 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-55.el7
- BUILDINFO: commit=8d4601c741d0a8c2bad6b36f6f5e18c4408bc290
- Modify cleanup-host script run during destroy (Borne Mace)

* Fri Oct 07 2016 Mick Thompson <michael.a.thompson@oracle.com> - 3.0.1-54.el7
- BUILDINFO: commit=0e5791170fa3471ef85d8bec72a2759b020a8ab5
- Updated murano configuration. (Mick Thompson)  
- Add aodh-api to haproxy.cfg file (Jeffrey Zhang)

* Fri Oct 07 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-53.el7
- BUILDINFO: commit=ee9a32016835489d0f562bf5d723f03473d56fe1
- Allow Neutron to be run in DVR mode (Paul Bourke)

* Thu Oct 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-52.el7
- BUILDINFO: commit=185c15aa338033ac9b36f1087a6cc6fef5496a60
- Disable some backend_ceph settings via rpm. (James McCarthy)

* Thu Oct 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-51.el7
- BUILDINFO: commit=cbadc921108e22d1e2ce59d3659a4bb6402cc976
- Missing dependency for kollacli predeploy checks. (James McCarthy)

* Thu Oct 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-50.el7
- BUILDINFO: commit=e29189823119360beebff53323618a0864424768
- Disable glance_backend_ceph and cinder_backend_ceph. (James McCarthy)  
- Heka template missing optional params (Paul Bourke)  
- Fix template for multiple physical networks (liyingjun)  
- Revert "Don't create br-ex on compute nodes" (Paul Bourke)

* Wed Oct 05 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-49.el7
- BUILDINFO: commit=1765b430ca542582819be8ab645c39400b9fee8c
- add upgrade.yml to aodh (zhubingbing)

* Wed Oct 05 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-48.el7
- BUILDINFO: commit=openstack-kolla-3.0.1-48
- Default storage engine is not enforced (Vladislav Belogrudov)  
- Fix horizon to use cache (Paul Bourke)  
- On swift upgrade, destroy swift_data along with the others. (James McCarthy)  
- Stops attempted start of tgtd container (Mark Duggan)  
- Allow service_checks to run independently of kolla-ansible (Paul Bourke)  
- cinder_volume_group is defined as "cinder_volumes" (Mark Duggan)  
- Fixes incorrect attempt to start tdt container (Mark Duggan)  
- Iscsid container fails to start on storage node when cinder is enabled (Mark Duggan)  
- Don't use /var/lib/kolla prefix for Glance data (Paul Bourke)  
- Missing URI for libvirt (stack)

* Fri Sep 30 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-47.el7
- Commented out lines which aren't code (stack)  
- Fix syntax error in Murano template (Paul Bourke)

* Wed Sep 28 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-46.el7
- Allow mysql to be used as a database for Ceilometer (Paul Bourke)  
- Remove check for enable_nova_libvirt in nova/ceph.yml (Paul Bourke)  
- Fixing release tag in docker-ostk (Mark Duggan)  
- Updating jinja2 version to 2.8 to fix deploy (Mark Duggan)  
- Cinder cannot use external non-LVM iSCSI storage (Vladislav Belogrudov)

* Tue Sep 27 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-45.el7
- Adjust logic in rabbitmq upgrade.yml. (James McCarthy)  
- Fix permission for /var/log/kolla folder (Jeffrey Zhang)  
- cinder-volume 'targetctl save' requires root (Paul Bourke)  
- add docker MountFlags=shared (Steve Noyes)

* Fri Sep 23 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-44.el7
- Fixes Toolbox Image Name (Mark Duggan)  
- Remove modprobe from nova-compute startup (Paul Bourke)

* Wed Sep 21 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-43.el7
- Remove ansible serial: option for haproxy and rabbitmq. (James McCarthy)

* Wed Sep 21 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-42.el7
- Fix haproxy entry for mysqlcluster (Paul Bourke)  
- Tokenise values for configuring Neutron jumbo frames (Paul Bourke)  
- Allow operators to provision multiple physical networks (Paul Bourke)  
- Fix "nova_libvirt_virt_type' is undefined" error (Mark Duggan)  
- Update rpm changelog for virtual_router_id changes. (James McCarthy)  
- Handle name change for the virtual_router_id property. (James McCarthy)  
- Fix up aodh config templates (Paul Bourke)  
- repair aodh image dockerfile (zhubingbing)  
- Add aodh role (zhubingbing)

* Mon Sep 19 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-40.el7
- remove no longer needed kollacli_hosts var (Steve Noyes)  
- Nova persistent data fixes (Paul Bourke)  
- Keystone template override to work with Mitaka (Paul Bourke)  
- Allow operators to customise keystone source install (Paul Bourke)

* Thu Sep 15 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-38.el7
- rpm spec fixes for pca (Steve Noyes)

* Wed Sep 14 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-37.el7
- Couple of fixes:   - Fixed issues with kolla-genpwd (pbr not being able to
  find the version)   - Force RPM to only allow the exact kolla RPMs as dep
  resolution on install   - Added the new openstack env vars that should be kept
  when sudo for kolla (Wiekus Beukes)

* Wed Sep 14 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-36.el7
- Added oracle default values override for all.yml - ie added %post processing that modify the all.yml at install / upgrdae to set the Oracle specific default values in all.yml (Wiekus Beukes)  [Orabug: 24662118] 
- align ceph with other svc patterns in inventory files (Steve Noyes)

* Wed Sep 14 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-35.el7
- fix the common upgrade (Jeffrey Zhang)  
- Add missing serial option for haproxy and mysqlcluster roles in site.yml that were missed during cherrypick. (Mick Thompson)  
- Added serial option to site.yml. (Mick Thompson)  
- Replace large named volumes with host bind mounts (Paul Bourke)

* Mon Sep 12 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-33.el7
- Updated to fix all the problems with the new kolla changes (Wiekus Beukes)  
- Fixed issue with /etc/kolla/config not existing by default (Wiekus Beukes)  
- add git init to rpm spec (Steve Noyes)  
- Remove ansible.cfg from kolla (Steve Noyes)  
- Restored database host in mysqlcluser role in site.yml. (Mick Thompson)  
- Added git as a BuilRequires (Wiekus Beukes)  
- Added missing database entries in all-in-one file (Borne Mace)  
- Fix mysqlcluster build (Paul Bourke)  
- Install Oracle built Ceph Jewel (Paul Bourke)  
- Build process outputs each line twice (Vladislav Belogrudov)  
- Replace git repo with url for mysqlcluster (Paul Bourke)  
- Change ceph version to Jewel (Michal (inc0) Jastrzebski)  
- Add header blocks to all Dockerfiles (Paul Bourke)  
- Update the oracle build profile (Paul Bourke)  
- Updated all.yml and build.conf values (Borne Mace)  
- Upgrade OpenStack DB (NDB) from O3L2.1.1 to O3L3.0.1 (Mick Thompson)  
- Update O3L kolla-build.conf to be compatible with latest keystone (Paul Bourke)  
- Install pip from yum rather than get-pip.py (Paul Bourke)  
- Allow operators to override use of get-pip.py (Paul Bourke)  
- Install Heka package locally (Paul Bourke)  
- Revert "neutron-linuxbridge-agent missing ipset and bridgeutils" (Paul Bourke)  
- Add option to support dhcp/l3 agent ha (liyingjun)  
- neutron-linuxbridge-agent missing ipset and bridgeutils (Paul Bourke)  
- Customizations for Neutron (Christian Berendt)  
- Add local copy of rabbitmq clusterer plugin (Paul Bourke)  
- Allow operators to customise rabbitmq plugins (Paul Bourke)  
- Add O3L base Dockerfile customisations (Paul Bourke)  
- Add kolla-build.conf for O3L (Paul Bourke)  
- Allow operators to override versionlock for redhat in base (Paul Bourke)  
- Add a block around oraclelinux base package install (Paul Bourke)

* Thu Jul 14 2016 Mark Duggan <mark.duggan@oracle.com> - 3.0.1-25.el7
- Fixing position iscsi utils package in Dockerfile (Mark Duggan)

* Thu Jul 07 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-24.el7
- libvirtd.conf is pushed to controllers by mistake (Vladislav Belogrudov)

* Tue Jul 05 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-23.el7
- Use inventory_hostname for Ceph bootstrap (Paul Bourke)  
- Add a check before wiping Ceph disks in bootstrap (Paul Bourke)

* Thu Jun 30 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-22.el7
- Updated docker-py requirement to 1.8.1 (Wiekus Beukes)  
- Fix ceph_disks bootstrap task conditional (Paul Bourke)  
- Fix Ceph deploy task when using separate storage nodes (Paul Bourke)

* Wed Jun 29 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-21.el7
- Adjust nova.conf template to clean up deprecated options (James McCarthy)  
- Mount /etc/iscsi required for boot-on-vol (Mark Duggan)  
- Changes needed for boot_on_vol to work (Mark Duggan)  
- Changes needed for cinder boot on vol to work (Mark Duggan)  
- Adjust to capture stdout using different technique from inside container See: https://github.com/docker/docker/issues/19616 (James McCarthy)  
- Ensure liberasurecode and related rpms are deleted post installation (James McCarthy)  
- Add OS_TENANT_NAME to the AUTO_VARS_FILE configuration, since: " The v2 file settings should work with OS_TENANT_NAME as it is interchangeable with OS_PROJECT_NAME." (James McCarthy)  
- Update the AIO inventory and adjust group mapping for neutron-server (put back into control - kollacli looks at AIO arrangement) (James McCarthy)

* Mon Jun 27 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-20.el7
- Allow Docker-Engine 1.12 (Wiekus Beukes)  
- Ensure rabbitmq-server and related rpms are deleted post installation (James McCarthy)

* Fri Jun 24 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-19.el7
- Fix another issue where osd were rebootstrapping (Paul Bourke)  
- Fix mons rebootstrapping (Paul Bourke)  
- Update ceph osd disk spec to be more user friendly (Paul Bourke)

* Mon Jun 20 2016 Paul Bourke <pauldbourke@gmail.com> - 3.0.1-18.el7
- Add check for already bootstrapped osds (Paul Bourke)  
- Update installation of rabbitmq-server and dependencies, copy list of rpms into container and install directly (mention of ca-artifacts or spb repos removed) (James McCarthy)  
- Update to use openstack21 as well as openstack20 repo Need to keep openstack20 as all needed packages are not available in openstack21 (python-pip) (James McCarthy)  
- Update to use openstack21 vs openstack20 repo (James McCarthy)  
- Update liberasure installation in swift-base to use Oracle built rpms (by copying them directly into container, rpms added to source control from http://ca-artifacts.us.oracle.com/auto-build/openstack30-7/x86_64/) (James McCarthy)  
- Update liberasure installation in swift-base to use Oracle built rpms (James McCarthy)

* Wed Jun 15 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-17.el7
- Only copy libvirtd.conf for Nova when enable_ceph (Paul Bourke)  
- Fix horizon assets issue (Paul Bourke)  
- Support both manual and auto ceph disk detection (Paul Bourke)

* Thu Jun 09 2016 Paul Bourke <paul.bourke@oracle.com> - 3.0.1-11.el7
- Add tasks to copy keys to /etc/libvirt on host for Xen (Paul Bourke)  
- Fix the incompatibility for ansible 2.1.0 (Jeffrey Zhang)  
- Bump the ansible to 2 (Jeffrey Zhang)  
- Manual ceph disk provisioning support (Paul Bourke)  
- Allow kolla_docker to work with py26 (Paul Bourke)  
- Port the necessary pieces to make Nova integrate with Ceph (Paul Bourke)

* Fri Jun 03 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-9.el7
- Change requires for openstack-kolla-user to force full removal when user RPM is removed (Wiekus Beukes)  
- Added missing aodh config files to etc/kolla/config. (Mick Thompson)  
- Fix admin user/tenant ids in tools/init-runonce (Paul Bourke)  
- Mitaka expects to find scsi_id without specifying full path (Vladislav Belogrudov)

* Tue May 31 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-8.el7
- haproxy service should start on controllers (Vladislav Belogrudov)  
- Add python-neutronclient specifically, it is missing from utils (James McCarthy)  
- Add ceph to oracle build profile (Paul Bourke)

* Wed May 25 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-7.el7
- Normalize ceph in all-in-one inventory (Steve Noyes)

* Wed May 25 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-5.el7
- fix typo in rpm spec file (Steve Noyes)

* Wed May 25 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-4.el7
- Split out kolla user creation into a new RPM (Wiekus Beukes)  
- Added missing hyphen in front of 'hosts: [aodh...' in site.yml. (Mick Thompson)

* Tue May 24 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 3.0.1-3.el7
- Fixed extra 'kollacli: new private ansible.cfg file' in useradd (Wiekus
  Beukes)

* Tue May 24 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-2.el7
- Move preinstall version to 3.0.1 in host precheck (Vladislav Belogrudov)  
- Added missing endif in ceilometer-central Dockerfile.j2 file. (Mick Thompson)  
- Mitaka Ceilometer to use Aodh for Alarms (Mick Thompson)

* Mon May 23 2016 - Steve Noyes <steve.noyes@oracle.com>
- added new private ansible cfg file

* Fri Apr 29 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Updated the Ansible requirement to 2.1.0

* Wed Mar 16 2016 - Mark Duggan <mark.duggan@oracle.com>
- Added libvirtd.conf and sysconfig/libvirtd changes to test live migration

* Mon Mar 07 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added oswatcher to the services to be disabled on OVM

* Mon Mar 07 2016 - Borne Mace <borne.mace@oracle.com>
- added some post operations to support group / host variables

* Mon Feb 22 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fix update issues
- Fix issue where libvirtd is always restarted
- Update the openstack_release if need be when updating

* Fri Feb 19 2016 - Mark Duggan <mark.duggan@oracle.com>
- Minor changes in libvirtd.conf in OVM Server (bug 22762921)

* Thu Feb 18 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added back the OL7 required pieces
- Changed OVM check since ovs-info will always not exist if in kickstart
- Make the post be repeatable to allow RPM updates

* Wed Feb 17 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Changes required for OVM Server (bug 22731949)

* Fri Nov 06 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixed /etc/kolla/config file permissions (bug 21983235)
- Fixed user creation issues (bug 22098605)

* Fri Oct 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Renamed the kolla-tools package to kolla-utils
- Added a check to make sure sudoers.d gets inlcuded by sudoers

* Wed Sep 23 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added the kolla-tools package

* Tue Sep 15 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added OL6 support

* Thu Sep 10 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed the useradd to not create the home dir and only create it if need be
- Renamed the inventory directory inventory_samples

* Tue Sep 08 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed %config to %config(noreplace)

* Fri Sep 04 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixing file permissions and leaving kolla user alone on uninstall
- Fixed issue where post would sometime error exiting
- Changed the SSH dir create to be post rather then forcefully laying it down
- Change the Ansible config file to disable host key checking

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

